# SnitchVis

Uses PyQt6 to render videos of [snitch](https://civwiki.org/wiki/Snitch) events from [Civ](https://civwiki.org/wiki/Main_Page) servers. Written for [CivMC](https://old.reddit.com/r/CivMC).

Can also be used as a desktop application for precision scrubbing and manipulating visualization speed and direction.

Used by [SnitchVisBot](https://github.com/tybug/snitchvisbot) to render snitches from discord.
